@@ -265,7 +265,7 @@ sub session_clear_expired
  else
  {
   ###FLAT###
-  remove_SF_OldSessions($tmp.'/',time()-$sys_time_for_flat_sess);
+  remove_SF_OldSessions($tmp,time()-$sys_time_for_flat_sess);
  }
  return(1);
 }
@@ -274,7 +274,7 @@ sub session_expire_update
  my ($dbh) = @_;
  my %calmin  = ('second',1,'minute',60,'hour',3600,'day',86400,'month',2678400,'year',31536000);
  my %globmin = ('s',1,'m',60,'h',3600,'d',86400,'M',2678400,'y',31536000);
- my $inter = $calmin{$sess_datetype};
+ my $inter = $sess_time * $calmin{$sess_datetype};
  $inter += time();
  my $i_id;
  if($sess_force_flat eq 'off') ###DB###
@@ -291,7 +291,7 @@ sub session_expire_update
  else
  {
   ###FLAT###
-  return(update_SF_File($tmp.'/',$sys_local_sess_id));
+  return(update_SF_File($tmp,$sys_local_sess_id));
  }
  return (1);
 }
@@ -300,7 +300,7 @@ sub insert_sessions_row   # ($session_id,$db_handler)
   my ($dbh) = @_;
   my %calmin  = ('second',1,'minute',60,'hour',3600,'day',86400,'month',2678400,'year',31536000);
   my %globmin = ('s',1,'m',60,'h',3600,'d',86400,'M',2678400,'y',31536000);
-  my $inter = $calmin{$sess_datetype};
+  my $inter = $sess_time * $calmin{$sess_datetype};
   $inter += time();
   my $sid = $sys_local_sess_id;
   my $ip = $ENV{'REMOTE_ADDR'}; # Get remote IP address
@@ -318,7 +318,7 @@ sub insert_sessions_row   # ($session_id,$db_handler)
   else
   {
    ###FLAT###
-   write_SF_File($tmp.'/',$sys_local_sess_id,'');
+   write_SF_File($tmp,$sys_local_sess_id,'');
    return(1);
   }
   return(0);
@@ -332,10 +332,10 @@ sub DB_OnDestroy
 #####################################################################
 sub SignUpUser
 {
- my ($user,$pass,$data,$dbh) = @_;
+ my ($user,$pass,$data,$active,$fname,$lname,$email,$dbh) = @_;
  my $ut = "SELECT USER FROM $sql_user_table WHERE USER=?";
- my $q = "INSERT INTO $sql_user_table VALUES (MAXVAL('ID|$sql_user_table'),?,?,?)";
- 
+ my $q = "INSERT INTO $sql_user_table VALUES (MAXVAL('ID|$sql_user_table'),?,?,?,?,?,?,?,?)";
+ $active = uc($active);
  my $rut = $dbh->prepare($ut);
  $rut->execute($user);
 
@@ -344,7 +344,7 @@ sub SignUpUser
  if ($arr[0] ne '') {return(0);}
  else
   {
-   my $res = $dbh->do($q,undef,$user,$pass,$data);
+   my $res = $dbh->do($q,undef,$user,$pass,$active,$data,time(),$fname,$lname,$email);
    $dbh->commit();
    if ($res eq '1')
      {
@@ -359,7 +359,7 @@ sub SignInUser
  my ($user,$pass,$dbh) = @_;
  $user = sql_quote($user,$dbh);
  $pass = sql_quote($pass,$dbh);
- my $q = "SELECT ID,DATA FROM $sql_user_table WHERE USER=$user and PASSWORD=$pass;";
+ my $q = "SELECT ID,DATA FROM $sql_user_table WHERE USER=$user and PASSWORD=$pass and ACTIVE='Y';";
  my $res = sql_query($q,$dbh);
  if ($res eq undef)
    {
